@@ -82,9 +82,29 @@ class TTRClient(object):
                 return int(c['counter'])
         return None
 
-    def get_categories(self):
-        """Get a list of all available categories"""
-        r = self._get_json({'op': 'getCategories'})
+    def get_categories(
+            self, 
+            unread_only=False,
+            enable_nested=False,
+            include_empty=False
+        ):
+        """
+        Get a list of all available categories
+        
+        :param unread_only: Only return categories containing unread articles.
+            Defaults to ``False``.
+        :param enable_nested: When enabled, traverse through sub-categories
+            and return only the **topmost** categories in a flat list.
+            Defaults to ``False``. 
+        :param include_empty: Include categories not containing any feeds.
+            Defaults to ``False``. *Requires server version 1.7.6*
+        """
+        r = self._get_json({
+            'op': 'getCategories',
+            'unread_only': unread_only,
+            'enable_nested': enable_nested,
+            'include_empty': include_empty
+        })
         return [Category(cat, self) for cat in r['content']]
 
     def get_feeds(
@@ -111,14 +131,55 @@ class TTRClient(object):
         r = self._get_json({'op': 'getFeeds', 'cat_id': cat_id})
         return [Feed(feed, self) for feed in r['content']]
 
-    def get_headlines(self, feed_id=0):
+    def get_headlines(
+            self,
+            feed_id=-4,
+            limit=0,
+            skip=0,
+            is_cat=False,
+            show_excerpt=True,
+            show_content=False,
+            view_mode=None,
+            include_attachments=False,
+            since_id=None,
+            include_nested=True,
+        ):
+
         """
         Get a list of headlines from a specified feed.
 
         :param feed_id: Feed id. This is available as the ``id`` property of
-            a Feed object.
+            a Feed object. Default is ``-4`` (all feeds).
+        :param limit: Return no more than this number of headlines. Default is
+            ``0`` (unlimited, though the server limits to 60).
+        :param skip: Skip this number of headlines. Useful for pagination.
+            Default is ``0``.
+        :param is_cat: The feed_id is a category. Defaults to ``False``.
+        :param show_excerpt: Include a short excerpt of the article. Defaults
+            to ``True``.
+        :param show_content: Include full article content. Defaults to 
+            ``False``.
+        :param view_mode: (string = all_articles, unread, adaptive, marked,
+            updated)
+        :param include_attachments: include article attachments. Defaults to
+            ``False``.
+        :param since_id: Only include headlines newer than ``since_id``.
+        :param include_nested: Include articles from child categories.
+            Defaults to ``True``.
         """
-        r = self._get_json({'op': 'getHeadlines', 'feed_id': feed_id})
+        r = self._get_json({
+            'op': 'getHeadlines',
+            'feed_id': feed_id,
+            'limit': limit,
+            'skip': skip,
+            'is_cat': is_cat,
+            'show_excerpt': show_excerpt,
+            'show_content': show_content,
+            'view_mode': view_mode,
+            'include_attachments': include_attachments,
+            'since_id': since_id,
+            'include_nested': include_nested,
+        })
         return [Headline(hl, self) for hl in r['content']]
 
     def get_articles(self, article_id):
@@ -200,6 +261,9 @@ class TTRClient(object):
 
 
 class RemoteObject(object):
+    """
+    This is the base class for representing remote resources as Python objects.
+    """
     def __init__(self, attr, client=None):
         self._client = client
         for key, value in attr.items():
@@ -210,6 +274,18 @@ class RemoteObject(object):
 
 class Category(RemoteObject):
     def feeds(self, **kwargs):
+        """
+        Get a list of feeds for this category.
+
+        :param unread_only: *Optional* Include only feeds containing unread
+            articles. Default is ``False``.
+        :param limit: *Optional* Limit number of included feeds to ``limit``.
+            Default is 0 (unlimited).
+        :param offset: *Optional* Skip this number of feeds. Useful for
+            pagination. Default is 0.
+        :param include_nested: *Optional* Include child categories. Default
+            is ``False``.
+        """
         return self._client.get_feeds(cat_id=self.id, **kwargs)
 
 
@@ -221,22 +297,60 @@ class Feed(RemoteObject):
         except AttributeError:
             pass
 
-    def headlines(self):
-        return self._client.get_headlines(feed_id=self.id)
+    def headlines(self, **kwargs):
+        """
+        Get a list of headlines from a this feed.
+
+        :param limit: Return no more than this number of headlines. Default is
+            ``0`` (unlimited, though the server limits to 60).
+        :param skip: Skip this number of headlines. Useful for pagination.
+            Default is ``0``.
+        :param show_excerpt: Include a short excerpt of the article. Defaults
+            to ``True``.
+        :param show_content: Include full article content. Defaults to 
+            ``False``.
+        :param view_mode: (string = all_articles, unread, adaptive, marked,
+            updated)
+        :param include_attachments: include article attachments. Defaults to
+            ``False``.
+        :param since_id: Only include headlines newer than ``since_id``.
+        :param include_nested: Include articles from child categories.
+            Defaults to ``True``.
+        """
+        return self._client.get_headlines(feed_id=self.id, **kwargs)
 
 
 class Headline(RemoteObject):
+    """This class represents Headline objects. A headline is a short version
+        of an article. 
+    """
+    def __init__(self, attr, client):
+        super(Headline, self).__init__(attr, client)
+        try:
+            self.updated = datetime.fromtimestamp(self.updated)
+        except AttributeError:
+            pass
     def full_article(self):
+        """Get the full article corresponding to this headline"""
         r = self._client.get_articles(self.id)
         return r[0]
 
 
 class Article(RemoteObject):
+    def __init__(self, attr, client):
+        super(Article, self).__init__(attr, client)
+        try:
+            self.updated = datetime.fromtimestamp(self.updated)
+        except AttributeError:
+            pass
     def publish(self):
+        """Share this article to published feed"""
         self._client.share_to_published(self.title, self.link, self.content)
 
     def refresh_status(self):
+        """Refresh this object with new data fetched from the server."""
         self._client.refresh_article(self)
 
     def toggle_unread(self):
+        """Toggle unread status of this article"""
         self._client.toggle_unread(self.id)
